%define major 5
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%define commit  2b69aed630e26fb2c700bba8c45f3bd012371c5c
%define date    20231220

Name:           kaldi-vosk
Version:        git%{date}
Release:        %mkrel 4
Summary:        Speech Recognition Toolkit
Group:          Sciences/Mathematics

License:        ASL 2.0
URL:            https://github.com/alphacep/kaldi
Source0:        https://github.com/alphacep/kaldi/archive/%{commit}.tar.gz

Patch1:         0001-kaldi-fix-Map-undefined.patch
Patch101:       kaldi-no-armv7-neon.patch
# CMake build fixes
Patch201:	0001-Fix-linking.patch
Patch202:	0002-Skip-RPATH.patch
Patch203:	0003-Fix-CMake-config-location.patch
Patch204:	0004-Add-lib-version.patch
#from Fedora
Patch300:   kaldi-fst.patch

BuildRequires:  openfst-devel
BuildRequires:  openblas-devel
BuildRequires:  glibc-devel
BuildRequires:  cmake


%description
Kaldi is a toolkit for speech recognition, intended for use by
speech recognition researchers and professionals.

%package -n  %{libname}
Summary:        Main library for kaldi
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
Obsoletes:      %{_lib}kaldi-lookahead < 1.8.0-2
Obsoletes:      %{_lib}kaldi-vosk < git20231220-3

%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with kaldi

%package -n  %{develname}
Summary:        Headers for kaldi
Group:          Development/C++
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{_lib}kaldi-lookahead-devel < 1.8.0-2
Conflicts:      %{_lib}kaldi-vosk < git20231220-3

%description -n %{develname}
This package contains headers for developing programs that will use kaldi

%prep
%autosetup -p1 -n kaldi-%{commit}

if [[ ! -f src/.version ]]; then
  echo "Fix %%kaldi_version"
  exit 1
fi

%build
%global kaldi_version $(cat src/.version)
%global kaldi_major $(echo %{kaldi_version} | cut -d. -f1)
%cmake \
  -DKALDI_VERSION:STRING="%{kaldi_version}" \
  -DKALDI_MAJOR:STRING="%{kaldi_major}" \
  -DKALDI_BUILD_EXE:BOOL=OFF \
  -DKALDI_BUILD_TEST:BOOL=OFF
%cmake_build

%install
%cmake_install

%files -n %{libname}
%license COPYING
%doc README.md
 %{_libdir}/libkaldi-*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/kaldi/
%{_libdir}/cmake/kaldi/
%{_libdir}/libkaldi-*.so


%changelog
* Thu May 01 2025 papoteur <papoteur> git20231220-4.mga10
+ Revision: 2180226
- rebuild for new openfst 1.8.4

* Sat Sep 07 2024 wally <wally> git20231220-3.mga10
+ Revision: 2093504
- build using CMake
- add patches to fix build with CMake
- add patch to add version and soversion to libraries

* Fri Sep 06 2024 papoteur <papoteur> git20231220-2.mga10
+ Revision: 2093414
- bump release
- new version to git snapshot from 2023-12-20
- add patch for recent openblas
- obsolete lib*openfst23-extensions

* Wed Sep 06 2023 papoteur <papoteur> git20230417-1.mga10
+ Revision: 1984740
- update to latest commit 20230417

* Mon Sep 26 2022 papoteur <papoteur> git20220817-3.mga9
+ Revision: 1892538
- Really obsolete kaldi-lookahead

* Sat Sep 17 2022 papoteur <papoteur> git20220817-2.mga9
+ Revision: 1889495
- update to snapshot of 2022-08-17
- Rename from lookahead to branch vosk, the old one doesn't exist anymore

* Sat Jun 11 2022 papoteur <papoteur> 1.8.0-1.mga9
+ Revision: 1863992
- imported package kaldi-lookahead

